@@ -15,49 +15,22 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-"""The client library for the LIGO Data Replicator (LDR) service.
+"""This library is deprecated, don't use it
 
-The DataFind service allows users to query for the location of
-Gravitational-Wave Frame (GWF) files containing data from the current
-LIGO and Virgo gravitational-wave detectors.
-
-This module defines the L{GWDataFindHTTPConnection} and
-L{GWDataFindHTTPSConnection} class objects, for connecting to an LDR
-server in open and authenticated access modes respectively.
-The authenticated L{GWDataFindHTTPSConnection} connection requires users
-have a valid X509 certificate that is registered with the server in
-question.
-
-A new connection can be opened as follows:
-
->>> from glue.datafind import GWDataFindHTTPConnection
->>> connection = GWDataFindHTTPConnection(host, port)
-
-and similar for the HTTPS version.
-
-Users on the LIGO Data Grid (LDG) can connect without giving the name of
-the relevant host, so long as the C{LIGO_DATAFIND_SERVER} environment
-variable is defined:
-
->>> connection = GWDataFindHTTPConnection()
-
-Queries for frames can be made using the
-L{find_frame_urls<GWDataFindHTTPConnection.find_frame_urls>} method of the
-relevant connection:
-
->>> cache = connection.find_frame_urls('L', 'L1_R', 1093564816, 1093651216)
-
-By default, the returned L{Cache<glue.lal.Cache>} object includes both
-C{gsiftp} and local C{file} versions of each frame, but the C{urlfile}
-keyword argument can be given to return only one of those:
-
->>> cache = connection.find_frame_urls('L', 'L1_R', 1093564816, 1093651216, urltype='file')
-
-See the documentation for each connection method for more detailed examples.
+Instead use `gwdatafind`, see https://gwdatafind.readthedocs.io.
 """
 
+# XXX THIS MODULE IS DEPRECATED, and should be removed in a future release
+# (>=glue-1.62.0).
+# The API in the replacement is _not_ identical, so we just want to leave
+# this in place as it is until downstream users update.
+
 from __future__ import (absolute_import, division)
 
+import warnings
+warnings.warn('this module has been replaced by gwdatafind and will be '
+              'removed in a future relase', DeprecationWarning)
+
 import os
 import sys
 import time
