@@ -393,17 +393,13 @@ def load_filename(filename, verbose = False, **kwargs):
 	"""
 	if verbose:
 		sys.stderr.write("reading %s ...\n" % (("'%s'" % filename) if filename is not None else "stdin"))
-	if filename is not None:
-		fileobj = open(filename, "rb")
+	if filename is None:
+		# In Python 3, ``sys.stdin`` has an attribute called
+		# ``buffer`` that is the underyling byte-oriented stream.
+		xmldoc, hexdigest = load_fileobj(sys.stdin.buffer if hasattr(sys.stdin, "buffer") else sys.stdin, **kwargs)
 	else:
-		fileobj = sys.stdin
-		# In Python 3, ``sys.stdin`` has an attribute called ``buffer`` that is the
-		# underyling byte-oriented stream.
-		try:
-			fileobj = fileobj.buffer
-		except AttributeError:
-			pass
-	xmldoc, hexdigest = load_fileobj(fileobj, **kwargs)
+		with open(filename, "rb") as fileobj:
+			xmldoc, hexdigest = load_fileobj(fileobj, **kwargs)
 	if verbose:
 		sys.stderr.write("md5sum: %s  %s\n" % (hexdigest, (filename if filename is not None else "")))
 	return xmldoc
@@ -427,21 +423,18 @@ def load_url(url, verbose = False, **kwargs):
 	"""
 	if verbose:
 		sys.stderr.write("reading %s ...\n" % (("'%s'" % url) if url is not None else "stdin"))
-	if url is not None:
+	if url is None:
+		# In Python 3, ``sys.stdin`` has an attribute called
+		# ``buffer`` that is the underyling byte-oriented stream.
+		xmldoc, hexdigest = load_fileobj(sys.stdin.buffer if hasattr(sys.stdin, "buffer") else sys.stdin, **kwargs)
+	else:
 		scheme, host, path = urllib.parse.urlparse(url)[:3]
 		if scheme.lower() in ("", "file") and host.lower() in ("", "localhost"):
-			fileobj = open(path, "rb")
+			fileobj = lambda: open(path, "rb")
 		else:
-			fileobj = urllib.request.urlopen(url)
-	else:
-		fileobj = sys.stdin
-		# In Python 3, ``sys.stdin`` has an attribute called ``buffer`` that is the
-		# underyling byte-oriented stream.
-		try:
-			fileobj = fileobj.buffer
-		except AttributeError:
-			pass
-	xmldoc, hexdigest = load_fileobj(fileobj, **kwargs)
+			fileobj = lambda: urllib.request.urlopen(url)
+		with fileobj() as fileobj:
+			xmldoc, hexdigest = load_fileobj(fileobj, **kwargs)
 	if verbose:
 		sys.stderr.write("md5sum: %s  %s\n" % (hexdigest, (url if url is not None else "")))
 	return xmldoc
@@ -554,8 +547,9 @@ def write_filename(xmldoc, filename, verbose = False, gz = False, with_mv = True
 		sys.stderr.write("writing %s ...\n" % (("'%s'" % filename) if filename is not None else "stdout"))
 	with SignalsTrap(trap_signals):
 		if filename is None:
-			# In Python 3, ``sys.stdout`` has an attribute called ``buffer`` that is
-			# the underyling byte-oriented stream.
+			# In Python 3, ``sys.stdout`` has an attribute
+			# called ``buffer`` that is the underyling
+			# byte-oriented stream.
 			fileobj = sys.stdout
 			try:
 				fileobj = fileobj.buffer
