@@ -35,7 +35,7 @@ from ligo import segments
 
 from glue import git_version
 from glue import iterutils
-from glue import segmentsUtils
+from ligo.segments import utils as segmentsUtils
 from .. import ligolw
 from .. import lsctables
 
@@ -324,7 +324,7 @@ class LigolwSegmentList(object):
 class LigolwSegments(set):
 	"""
 	An interface shim between code that makes use of segments in
-	glue.segments form, and LIGO Light-Weight XML I/O code.
+	ligo.segments form, and LIGO Light-Weight XML I/O code.
 
 	This class is "attached" to an XML document object, at which time
 	it parses and extracts the segment lists from the document, and
